//#define XERR
#include "costs.ih"

void Costs::writeParameters(ostream &out) const
{
    out << 
        "   costs:\n"
        "      discount reference age: " << d_referenceAge << "\n"
        "      discount proportion:    " << d_discountProportion << "\n"
        "      biopsy costs:           " << d_biop << '\n';
    
    for (size_t idx = 0; idx != d_treatment.size(); ++idx)
        out << 
            "      cost for tumor diameter: >= " << 
                setw(6) << d_treatment[idx].first << " mm. : " <<
                setw(4) << d_treatment[idx].second << '\n';

    out.put('\n');
}
